@@ -17,7 +17,7 @@ class Supporter(BaseModel):
     last_support: datetime | None = Field(None, alias="lastSupport")
     supporter_name: str = Field(..., alias="supporterName")
     supporter_avatar: AnyHttpUrl | None = Field(None, alias="supporterAvatar")
-    supporter_link: str = Field(..., alias="supporterLink")
+    supporter_link: str | None = Field(None, alias="supporterLink")
     supporter_id: UserID = Field(..., alias="supporterId")
     mutes: list
     muted_by_streamer: bool = Field(..., alias="mutedByStreamer")
